Class: GithubDailyUpdate::Reporter::Merged
- Defined in:
- lib/github_daily_update/reporters/merged.rb
Overview
This reporter generates a list of all the pull-requests that have been merged in the last 24 hours.
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
Constructor Details
This class inherits a constructor from GithubDailyUpdate::Reporter::Base
Instance Method Details
#generate ⇒ Object
4 5 6 7 8 |
# File 'lib/github_daily_update/reporters/merged.rb', line 4 def generate output = "## Merge Report\n\n" output += events(merged_pull_requests).join("\n") output end |